package com.xiesx.fastboot.base.pagination;

import java.util.List;
import java.util.Map;

import org.springframework.data.domain.Page;

import com.google.common.collect.Lists;
import lombok.NonNull;

/**
 * @title PaginationHelper.java
 * @description 分页帮助类
 * @author Sixian.xie
 * @date 2020-7-21 22:29:17
 */
public class PaginationHelper {

    /**
     * 构造
     *
     * @param page
     * @return
     */
    public static <T> PaginationResult<T> create(Page<T> page) {
        return create(page.getContent(), (int) page.getTotalElements());
    }

    /**
     * 构造
     *
     * @param page
     * @return
     */
    public static <T> PaginationResult<T> create(Page<T> page, Map<String, Object> extData) {
        PaginationResult<T> paginationResult = create(page.getContent(), (int) page.getTotalElements());
        paginationResult.extData = extData;
        return paginationResult;
    }

    /**
     * 构造空的返回
     * @return
     */
    public static <T> PaginationResult<T> createEmpty() {
        return PaginationResult.<T>builder().code(1).msg("No data").data(Lists.newArrayList()).count(0).build();
    }

    /**
     * 构造
     *
     * @param data
     * @param total
     * @return
     */
    public static <T> PaginationResult<T> create(@NonNull List<T> data, Integer total) {
        List<T> list = Lists.newArrayList(data);
        if (list.isEmpty()) {
            return PaginationResult.<T>builder().code(1).msg("No data").data(Lists.newArrayList()).count(0).build();
        } else {
            return PaginationResult.<T>builder().code(0).data(list).count(total).build();
        }
    }

    /**
     * 构造
     *
     * @param data
     * @param total
     * @return
     */
    public static <T> PaginationResult<T> create(@NonNull List<T> data, Integer total, Integer page) {
        List<T> list = Lists.newArrayList(data);
        if (list.isEmpty()) {
            return PaginationResult.<T>builder().code(1).msg("No data").data(Lists.newArrayList()).count(0).page(1).build();
        } else {
            return PaginationResult.<T>builder().code(0).data(list).count(total).page(page).build();
        }
    }
}
