package com.xiesx.fastboot.base.result;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.parser.Feature;
import lombok.NonNull;

import java.util.List;

public class R {

    /** 成功 */
    public static <T> BaseResult<T> succ() {
        return BaseResult.<T>builder().code(BaseResult.SUCCESS).msg(BaseResult.OP_MSG_SUCC).build();
    }

    public static <T> BaseResult<T> succ(@NonNull String msg) {
        return BaseResult.<T>builder().code(BaseResult.SUCCESS).msg(msg).build();
    }

    public static <T> BaseResult<T> succ(T data) {
        if(data == null){
            return succ();
        }
        return BaseResult.<T>builder().code(BaseResult.SUCCESS).msg(BaseResult.OP_MSG_SUCC).data(data).build();
    }

    public static <T, E> BaseResult<T> succ(T data, E extData) {
        if(data == null){
            return succ();
        }
        return BaseResult.<T>builder().code(BaseResult.SUCCESS).msg(BaseResult.OP_MSG_SUCC).data(data).extData(extData).build();
    }

    public static <T> BaseResult<T> succ(@NonNull String msg, @NonNull T data) {
        return BaseResult.<T>builder().code(BaseResult.SUCCESS).msg(msg).data(data).build();
    }

    public static <T> BaseResult<T> succ(@NonNull Integer code, @NonNull String msg) {
        return BaseResult.<T>builder().code(code).msg(msg).build();
    }

    public static <T> BaseResult<T> succ(@NonNull Integer code, @NonNull String msg, @NonNull T data) {
        return BaseResult.<T>builder().code(code).msg(msg).data(data).build();
    }

    /** 失败 */
    public static <T> BaseResult<T> fail() {
        return BaseResult.<T>builder().code(BaseResult.FAIL).msg(BaseResult.OP_MSG_FAIL).build();
    }

    public static <T> BaseResult<T> fail(@NonNull String msg) {
        return BaseResult.<T>builder().code(BaseResult.FAIL).msg(msg).build();
    }

    public static <T> BaseResult<T> fail(@NonNull T data) {
        return BaseResult.<T>builder().code(BaseResult.FAIL).msg(BaseResult.OP_MSG_FAIL).data(data).build();
    }

    public static <T> BaseResult<T> fail(@NonNull String msg, T data) {
        return BaseResult.<T>builder().code(BaseResult.FAIL).msg(msg).data(data).build();
    }

    public static <T> BaseResult<T> fail(@NonNull Integer code, @NonNull String msg) {
        return BaseResult.<T>builder().code(code).msg(msg).build();
    }

    public static <T> BaseResult<T> fail(@NonNull Integer code, @NonNull String msg, T data) {
        return BaseResult.<T>builder().code(code).msg(msg).data(data).build();
    }

    /** 异常 */
    public static <T> BaseResult<T> error() {
        return BaseResult.<T>builder().code(BaseResult.ERROR).msg(BaseResult.OP_MSG_FAIL).build();
    }

    public static <T> BaseResult<T> error(@NonNull String msg) {
        return BaseResult.<T>builder().code(BaseResult.ERROR).msg(msg).build();
    }

    public static <T> BaseResult<T> error(@NonNull T data) {
        return BaseResult.<T>builder().code(BaseResult.ERROR).msg(BaseResult.OP_MSG_FAIL).data(data).build();
    }

    public static <T> BaseResult<T> error(@NonNull String msg, T data) {
        return BaseResult.<T>builder().code(BaseResult.ERROR).msg(msg).data(data).build();
    }

    public static <T> BaseResult<T> error(@NonNull Integer code, @NonNull String msg) {
        return BaseResult.<T>builder().code(code).msg(msg).build();
    }

    public static <T> BaseResult<T> error(@NonNull Integer code, @NonNull String msg, T data) {
        return BaseResult.<T>builder().code(code).msg(msg).data(data).build();
    }

    /** 重试 */
    public static <T> BaseResult<T> retry() {
        return BaseResult.<T>builder().code(BaseResult.RETRY).msg(BaseResult.OP_MSG_FAI_RETRY).build();
    }

    public static <T> BaseResult<T> retry(@NonNull String msg) {
        return BaseResult.<T>builder().code(BaseResult.RETRY).msg(msg).build();
    }

    public static <T> BaseResult<T> retry(@NonNull T data) {
        return BaseResult.<T>builder().code(BaseResult.RETRY).msg(BaseResult.OP_MSG_FAI_RETRY).data(data).build();
    }

    public static <T> BaseResult<T> retry(@NonNull String msg, T data) {
        return BaseResult.<T>builder().code(BaseResult.RETRY).msg(msg).data(data).build();
    }

    public static <T> BaseResult<T> retry(@NonNull Integer code, @NonNull String msg) {
        return BaseResult.<T>builder().code(code).msg(msg).build();
    }

    public static <T> BaseResult<T> retry(@NonNull Integer code, @NonNull String msg, T data) {
        return BaseResult.<T>builder().code(code).msg(msg).data(data).build();
    }

    /** str 转 jsonObject */
    public static <T> T parseObject(String text, Class<T> clazz) {
        return JSON.parseObject(text, clazz, new Feature[0]);
    }

    /** str 转 jsonArray */
    public static <T> List<T> parseArray(String text, Class<T> clazz) {
        return JSON.parseArray(text, clazz);
    }
}
